@@ -1,6 +1,10 @@
 from datetime import datetime
 from couchdbcurl.client import Document
 
+import random
+from django.contrib.auth.models import get_hexdigest, check_password
+        
+
 
 class User(Document):
 
@@ -40,12 +44,19 @@ class User(Document):
     def set_password(self, raw_password):
         """This is copy-paste from django.contrib.auth.models.User.set_password()"""
         
-        import random
-        from django.contrib.auth.models import get_hexdigest
-        
         algo = 'sha1'
         salt = get_hexdigest(algo, str(random.random()), str(random.random()))[:5]
         hsh = get_hexdigest(algo, salt, raw_password)
         self.password = '%s$%s$%s' % (algo, salt, hsh)
         
-        
+
+    def check_password(self, raw_password):
+        """
+        Returns a boolean of whether the raw_password was correct. Handles
+        encryption formats behind the scenes.
+
+        (c) django.contrib.auth.models.User.check_password()
+        """
+        # Backwards-compatibility check. Older passwords won't include the
+        # algorithm or salt.
+        return check_password(raw_password, self.password)
